==> simg-1.0.0.21.zip: simg-project/application/view/compile/aa59d0b633c1f5e264787b2a357b83c011a7e190.file.article.tpl.php <==
<?php /* Smarty version Smarty-3.1.19, created on 2015-04-24 11:48:00
         compiled from "C:\Users\yoshitake\Documents\User\products\simg\develop\simg-project\application\view\template\article.tpl" */ ?>
<?php /*%%SmartyHeaderCode:4033547d2f6a329142-92746187%%*/if(!defined('SMARTY_DIR')) exit('no direct access allowed');
$_valid = $_smarty_tpl->decodeProperties(array (
  'file_dependency' => 
  array (
    'aa59d0b633c1f5e264787b2a357b83c011a7e190' => 
    array (
      0 => 'C:\\Users\\yoshitake\\Documents\\User\\products\\simg\\develop\\simg-project\\application\\view\\template\\article.tpl',
      1 => 1429868876,
      2 => 'file',
    ),
    'e33b4fc545922d2922a97eb692021e9a2d83875c' => 
    array (
      0 => 'C:\\Users\\yoshitake\\Documents\\User\\products\\simg\\develop\\simg-project\\application\\view\\template\\top.tpl',
      1 => 1429865747,
      2 => 'file',
    ),
    '0f6400e5bd88edcfc90ce21e2b8330fc68e25b72' => 
    array (
      0 => 'C:\\Users\\yoshitake\\Documents\\User\\products\\simg\\develop\\simg-project\\application\\view\\template\\base.tpl',
      1 => 1429865300,
      2 => 'file',
    ),
  ),
  'nocache_hash' => '4033547d2f6a329142-92746187',
  'function' => 
  array (
  ),
  'version' => 'Smarty-3.1.19',
  'unifunc' => 'content_547d2f6a711237_87643908',
  'has_nocache_code' => false,
),false); /*/%%SmartyHeaderCode%%*/?>
<?php if ($_valid && !is_callable('content_547d2f6a711237_87643908')) {function content_547d2f6a711237_87643908($_smarty_tpl) {?><?php if (!is_callable('smarty_modifier_truncate')) include 'C:\\Users\\yoshitake\\Documents\\User\\Tools\\Smarty\\Smarty-3.1.19\\libs\\plugins\\modifier.truncate.php';
?><!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN""http://www.w3.org/TR/html4/loose.dtd">
<html lang="ja">
	<head>
		<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
		<link rel="stylesheet" href="<?php echo function_url(array('directory'=>((string)@constant('APP_NAME')),'query'=>((string)@constant('SIMG_PARAM_EVENT'))."=".((string)@constant('EVENT_CSS'))),$_smarty_tpl);?>
" type="text/css" />
		<script language="javascript" src="<?php echo function_url(array('directory'=>((string)@constant('APP_NAME')),'query'=>((string)@constant('SIMG_PARAM_EVENT'))."=".((string)@constant('EVENT_JS'))),$_smarty_tpl);?>
"></script>
		<title><?php echo $_smarty_tpl->getConfigVariable('PAGE_CAPTION');?>
</title>
		
		
	</head>
	<body>
		<div id="wrapper">
			<div id="header">
				
					<p><a href="<?php echo function_url(array('directory'=>((string)@constant('APP_NAME'))),$_smarty_tpl);?>
"><?php echo $_smarty_tpl->getConfigVariable('PAGE_TITLE');?>
</a></p>
				
			</div>
			<div id="commandbar">
				
	<a href="<?php echo function_url(array('directory'=>((string)@constant('APP_NAME')),'query'=>((string)@constant('SIMG_PARAM_EVENT'))."=".((string)@constant('EVENT_LOGOFF'))),$_smarty_tpl);?>
"><?php echo $_smarty_tpl->getConfigVariable('LOGOFF');?>
</a>

			</div>
			<div id="container">
				
					<div id="contents">
						
	<?php  $_smarty_tpl->tpl_vars['article'] = new Smarty_Variable; $_smarty_tpl->tpl_vars['article']->_loop = false;
 $_from = $_smarty_tpl->tpl_vars['articles']->value; if (!is_array($_from) && !is_object($_from)) { settype($_from, 'array');}
foreach ($_from as $_smarty_tpl->tpl_vars['article']->key => $_smarty_tpl->tpl_vars['article']->value) {
$_smarty_tpl->tpl_vars['article']->_loop = true;
?>
		<div id="article_date"><?php echo $_smarty_tpl->tpl_vars['article']->value[@constant('AT_DATE')];?>
</div>
		<div id="article_title"><a href="<?php echo function_url(array('directory'=>((string)@constant('APP_NAME')),'query'=>((string)@constant('SIMG_PARAM_EVENT'))."=".((string)@constant('EVENT_MORE'))."&".((string)@constant('P_ITEM'))."=".((string)$_smarty_tpl->tpl_vars['article']->value[@constant('AT_ID')])."&".((string)@constant('P_OFFSET'))."=".((string)$_smarty_tpl->tpl_vars['current_offset']->value)),$_smarty_tpl);?>
"><?php echo $_smarty_tpl->tpl_vars['article']->value[@constant('AT_TITLE')];?>
</a></div>
		<div><?php echo smarty_modifier_truncate($_smarty_tpl->tpl_vars['article']->value[@constant('AT_CONTENT')],150);?>
</div>
		<p class="clear_right" />
	<?php } ?>
	<?php if (isset($_smarty_tpl->tpl_vars['nextart']->value)) {?>
		<div id="article_pager_next">
		[<a href="<?php echo $_smarty_tpl->tpl_vars['nextart']->value;?>
"><?php echo $_smarty_tpl->getConfigVariable('NEXT_PAGE');?>
</a>]
		</div>
	<?php }?>
	<?php if (isset($_smarty_tpl->tpl_vars['backart']->value)) {?>
		<div id="article_pager_back">
		[<a href="<?php echo $_smarty_tpl->tpl_vars['backart']->value;?>
"><?php echo $_smarty_tpl->getConfigVariable('BACK_PAGE');?>
</a>]
		</div>
	<?php }?>
	<p class="clear_both" />

					</div>
					<div id="sidebar">
						
	<p>
	<ul id="navi">
		<?php  $_smarty_tpl->tpl_vars['topic'] = new Smarty_Variable; $_smarty_tpl->tpl_vars['topic']->_loop = false;
 $_from = $_smarty_tpl->tpl_vars['topics']->value; if (!is_array($_from) && !is_object($_from)) { settype($_from, 'array');}
foreach ($_from as $_smarty_tpl->tpl_vars['topic']->key => $_smarty_tpl->tpl_vars['topic']->value) {
$_smarty_tpl->tpl_vars['topic']->_loop = true;
?>
			<?php if ($_smarty_tpl->tpl_vars['topic']->value[@constant('AT_KEY')]==$_smarty_tpl->tpl_vars['current_topic']->value) {?>
				<?php $_smarty_tpl->tpl_vars['option'] = new Smarty_variable(' id="current"', null, 0);?>
			<?php } else { ?>
				<?php $_smarty_tpl->tpl_vars['option'] = new Smarty_variable('', null, 0);?>
			<?php }?>
			<li<?php echo $_smarty_tpl->tpl_vars['option']->value;?>
><a href="<?php echo function_url(array('directory'=>((string)@constant('APP_NAME')),'query'=>((string)@constant('SIMG_PARAM_EVENT'))."=".((string)@constant('EVENT_TOPIC'))."&".((string)@constant('P_ITEM'))."=".((string)$_smarty_tpl->tpl_vars['topic']->value[@constant('AT_KEY')])),$_smarty_tpl);?>
"><?php echo $_smarty_tpl->tpl_vars['topic']->value[@constant('AT_NAME')];?>
</a></li>
		<?php } ?>
	</ul>
	</p>

					</div>
				
			</div>
			<div id="footer">
				
					<p>Copyright 2014- System Concept All rights reserved.</p>
				
			</div>
		</div>
	</body>
</html>
<?php }} ?>

==> simg-2.0.30.zip: simg-project/application/view/compile/aa59d0b633c1f5e264787b2a357b83c011a7e190.file.article.tpl.php <==
<?php /* Smarty version Smarty-3.1.19, created on 2015-04-28 14:33:16
         compiled from "C:\Users\yoshitake\Documents\User\products\simg\develop\simg-project\application\view\template\article.tpl" */ ?>
<?php /*%%SmartyHeaderCode:4033547d2f6a329142-92746187%%*/if(!defined('SMARTY_DIR')) exit('no direct access allowed');
$_valid = $_smarty_tpl->decodeProperties(array (
  'file_dependency' => 
  array (
    'aa59d0b633c1f5e264787b2a357b83c011a7e190' => 
    array (
      0 => 'C:\\Users\\yoshitake\\Documents\\User\\products\\simg\\develop\\simg-project\\application\\view\\template\\article.tpl',
      1 => 1429868876,
      2 => 'file',
    ),
    'e33b4fc545922d2922a97eb692021e9a2d83875c' => 
    array (
      0 => 'C:\\Users\\yoshitake\\Documents\\User\\products\\simg\\develop\\simg-project\\application\\view\\template\\top.tpl',
      1 => 1429865747,
      2 => 'file',
    ),
    '0f6400e5bd88edcfc90ce21e2b8330fc68e25b72' => 
    array (
      0 => 'C:\\Users\\yoshitake\\Documents\\User\\products\\simg\\develop\\simg-project\\application\\view\\template\\base.tpl',
      1 => 1430223271,
      2 => 'file',
    ),
  ),
  'nocache_hash' => '4033547d2f6a329142-92746187',
  'function' => 
  array (
  ),
  'version' => 'Smarty-3.1.19',
  'unifunc' => 'content_547d2f6a711237_87643908',
  'has_nocache_code' => false,
),false); /*/%%SmartyHeaderCode%%*/?>
<?php if ($_valid && !is_callable('content_547d2f6a711237_87643908')) {function content_547d2f6a711237_87643908($_smarty_tpl) {?><?php if (!is_callable('smarty_modifier_truncate')) include 'C:\\Users\\yoshitake\\Documents\\User\\Tools\\Smarty\\Smarty-3.1.19\\libs\\plugins\\modifier.truncate.php';
?><!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN""http://www.w3.org/TR/html4/loose.dtd">
<html lang="ja">
	<head>
		<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
		<link rel="stylesheet" href="<?php echo function_script(array('directory'=>((string)@constant('APP_NAME')),'path'=>'styles.css'),$_smarty_tpl);?>
" type="text/css" />
		<script language="javascript" src="<?php echo function_script(array('directory'=>((string)@constant('APP_NAME')),'path'=>'vote.js'),$_smarty_tpl);?>
"></script>
		<title><?php echo $_smarty_tpl->getConfigVariable('PAGE_CAPTION');?>
</title>
		
		
	</head>
	<body>
		<div id="wrapper">
			<div id="header">
				
					<p><a href="<?php echo function_url(array('directory'=>((string)@constant('APP_NAME'))),$_smarty_tpl);?>
"><?php echo $_smarty_tpl->getConfigVariable('PAGE_TITLE');?>
</a></p>
				
			</div>
			<div id="commandbar">
				
	<a href="<?php echo function_url(array('directory'=>((string)@constant('APP_NAME')),'query'=>((string)@constant('SIMG_PARAM_EVENT'))."=".((string)@constant('EVENT_LOGOFF'))),$_smarty_tpl);?>
"><?php echo $_smarty_tpl->getConfigVariable('LOGOFF');?>
</a>

			</div>
			<div id="container">
				
					<div id="contents">
						
	<?php  $_smarty_tpl->tpl_vars['article'] = new Smarty_Variable; $_smarty_tpl->tpl_vars['article']->_loop = false;
 $_from = $_smarty_tpl->tpl_vars['articles']->value; if (!is_array($_from) && !is_object($_from)) { settype($_from, 'array');}
foreach ($_from as $_smarty_tpl->tpl_vars['article']->key => $_smarty_tpl->tpl_vars['article']->value) {
$_smarty_tpl->tpl_vars['article']->_loop = true;
?>
		<div id="article_date"><?php echo $_smarty_tpl->tpl_vars['article']->value[@constant('AT_DATE')];?>
</div>
		<div id="article_title"><a href="<?php echo function_url(array('directory'=>((string)@constant('APP_NAME')),'query'=>((string)@constant('SIMG_PARAM_EVENT'))."=".((string)@constant('EVENT_MORE'))."&".((string)@constant('P_ITEM'))."=".((string)$_smarty_tpl->tpl_vars['article']->value[@constant('AT_ID')])."&".((string)@constant('P_OFFSET'))."=".((string)$_smarty_tpl->tpl_vars['current_offset']->value)),$_smarty_tpl);?>
"><?php echo $_smarty_tpl->tpl_vars['article']->value[@constant('AT_TITLE')];?>
</a></div>
		<div><?php echo smarty_modifier_truncate($_smarty_tpl->tpl_vars['article']->value[@constant('AT_CONTENT')],150);?>
</div>
		<p class="clear_right" />
	<?php } ?>
	<?php if (isset($_smarty_tpl->tpl_vars['nextart']->value)) {?>
		<div id="article_pager_next">
		[<a href="<?php echo $_smarty_tpl->tpl_vars['nextart']->value;?>
"><?php echo $_smarty_tpl->getConfigVariable('NEXT_PAGE');?>
</a>]
		</div>
	<?php }?>
	<?php if (isset($_smarty_tpl->tpl_vars['backart']->value)) {?>
		<div id="article_pager_back">
		[<a href="<?php echo $_smarty_tpl->tpl_vars['backart']->value;?>
"><?php echo $_smarty_tpl->getConfigVariable('BACK_PAGE');?>
</a>]
		</div>
	<?php }?>
	<p class="clear_both" />

					</div>
					<div id="sidebar">
						
	<p>
	<ul id="navi">
		<?php  $_smarty_tpl->tpl_vars['topic'] = new Smarty_Variable; $_smarty_tpl->tpl_vars['topic']->_loop = false;
 $_from = $_smarty_tpl->tpl_vars['topics']->value; if (!is_array($_from) && !is_object($_from)) { settype($_from, 'array');}
foreach ($_from as $_smarty_tpl->tpl_vars['topic']->key => $_smarty_tpl->tpl_vars['topic']->value) {
$_smarty_tpl->tpl_vars['topic']->_loop = true;
?>
			<?php if ($_smarty_tpl->tpl_vars['topic']->value[@constant('AT_KEY')]==$_smarty_tpl->tpl_vars['current_topic']->value) {?>
				<?php $_smarty_tpl->tpl_vars['option'] = new Smarty_variable(' id="current"', null, 0);?>
			<?php } else { ?>
				<?php $_smarty_tpl->tpl_vars['option'] = new Smarty_variable('', null, 0);?>
			<?php }?>
			<li<?php echo $_smarty_tpl->tpl_vars['option']->value;?>
><a href="<?php echo function_url(array('directory'=>((string)@constant('APP_NAME')),'query'=>((string)@constant('SIMG_PARAM_EVENT'))."=".((string)@constant('EVENT_TOPIC'))."&".((string)@constant('P_ITEM'))."=".((string)$_smarty_tpl->tpl_vars['topic']->value[@constant('AT_KEY')])),$_smarty_tpl);?>
"><?php echo $_smarty_tpl->tpl_vars['topic']->value[@constant('AT_NAME')];?>
</a></li>
		<?php } ?>
	</ul>
	</p>

					</div>
				
			</div>
			<div id="footer">
				
					<p>Copyright 2014- System Concept All rights reserved.</p>
				
			</div>
		</div>
	</body>
</html>
<?php }} ?>
